@@ -218,7 +218,7 @@ def view_invoices(timesheet: model.Timesheet):
     _, days_in_this_month = calendar.monthrange(today.year, today.month)
     month_last_day = datetime.datetime(today.year, today.month, days_in_this_month)
     month_middle = datetime.datetime(today.year, today.month, 15)
-    submittal_due_date = month_last_day if today < month_middle else month_last_day
+    submittal_due_date = month_middle if today < month_middle else month_last_day
     submittal_due_from_now_delta = (
         submittal_due_date - today + datetime.timedelta(days=1)
     )
